using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

namespace Components.Calendar.DayCal.Class.Event
{
    /// <summary>
    /// EventArgs of a MeetingAsking
    /// </summary>
    public class MeetingEventArgs : EventArgs
    {
        #region Variables
        /// <summary>
        /// DateToDisplay which contains the whole information
        /// </summary>
        private MeetingRow vMeetingRow;
        #endregion

        #region Constructeur
        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="_MeetingRow">DateToDisplay actor of the Add or the modification</param>
        public MeetingEventArgs(MeetingRow _MeetingRow) { vMeetingRow = _MeetingRow; }
        #endregion

        #region Accesseurs
        /// <summary>
        /// Gets the date of the meeting data
        /// </summary>
        public MeetingRow MeetingRow { get { return this.vMeetingRow; } }
        #endregion
    }
    /// <summary>
    /// EventArgs for a Date to Display change
    /// </summary>
    public class DisplayDateEventArgs : EventArgs
    {
        #region Variables
        /// <summary>
        /// DateTime which contains the date to display
        /// </summary>
        private DateTime vDateToDisplay;
        /// <summary>
        /// DateTime which contains the date before change
        /// </summary>
        private DateTime vDateBeforeChange;

        #endregion

        #region Constructeur
        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="_DateToDisplay">DateTime which contains the date to display</param>
        /// <param name="_DateBeforeChange">DateTime which contains the date before change</param>
        public DisplayDateEventArgs(DateTime _DateToDisplay, DateTime _DateBeforeChange)
            : base()
        {
            this.vDateToDisplay = _DateToDisplay;
            this.vDateBeforeChange = _DateBeforeChange;
        }
        #endregion

        #region Accesseurs
        /// <summary>
        /// Gets the date to display
        /// </summary>
        public DateTime DateToDisplay { get { return this.vDateToDisplay; } }
        /// <summary>
        /// Gets the date before change
        /// </summary>
        public DateTime DateBeforeChange { get { return this.vDateBeforeChange; } }
        #endregion
    }
    /// <summary>
    /// Represents the method that will handle an MeetingCreation event that has MeetingEventArgs data
    /// </summary>
    /// <param name="sender">Event sender</param>
    /// <param name="args">Information about the clicked day</param>    
    [Serializable]
    [ComVisible(true)]
    public delegate void MeetingEventHandler(object sender, MeetingEventArgs args);
    /// <summary>
    /// Represents the method that will handle an MeetingCreation event that has MeetingEventArgs data
    /// </summary>
    /// <param name="sender">Event sender</param>
    /// <param name="args">Information about the clicked day</param>    
    [Serializable]
    [ComVisible(true)]
    public delegate void MeetingModificationEventHandler(object sender, MeetingEventArgs args);
    /// <summary>
    /// Represents the method that will handle an DisplayDateChanged event that has DisplayDateEventArgs data
    /// </summary>
    /// <param name="sender">Event sender</param>
    /// <param name="args">Information about the change of date</param>    
    [Serializable]
    [ComVisible(true)]
    public delegate void DisplayDateEventHandler(object sender, DisplayDateEventArgs args);

}
